@@ -146,7 +146,7 @@ start-up modules.
 
 
 # set the version:
-$PDL::VERSION = '2.4.11'; # Go to sub numbering per git push
+$PDL::VERSION = '2.007';     # Go to sub numbering per git push
 
 # Main loader of standard PDL package
 
@@ -191,7 +191,23 @@ die $@ if $@;
 # properly recognizes the PDL package.
 package PDL;
 
+##################################################
+# Rudimentary handling for multiple Perl threads #
+##################################################
+my $clone_skip_should_be_quiet = 0;
+sub CLONE_SKIP {
+    warn("* If you need to share PDL data across threads, use memory mapped data, or\n"
+		. "* check out PDL::Parallel::threads, available on CPAN.\n"
+        . "* You can silence this warning by saying `PDL::no_clone_skip_warning;'\n"
+        . "* before you create your first thread.\n")
+        unless $clone_skip_should_be_quiet;
+    PDL::no_clone_skip_warning();
+    # Whether we warned or not, always return 1 to tell Perl not to clone PDL data
+    return 1;
+}
+sub no_clone_skip_warning {
+    $clone_skip_should_be_quiet = 1;
+}
 
 # Exit with OK status
-
 1;
